@@ -26,11 +26,10 @@ void  update_Cov(double *Cov, double *priorCov, double *SSgam, double *marg_prob
 
 void insert_model_tree(struct Node *tree, struct Var *vars,  int n, int *model, int num_models);
  
-SEXP mcmcbas(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP incint, SEXP Ralpha,SEXP method, SEXP modelprior, SEXP Rupdate, SEXP Rbestmodel, SEXP Rbestmarg, SEXP plocal, SEXP BURNIN_Iterations, SEXP MCMC_Iterations, SEXP LAMBDA, SEXP DELTA)
+SEXP mcmcbas(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP incint, SEXP Ralpha,SEXP method, SEXP modelprior, SEXP Rupdate, SEXP Rbestmodel,  SEXP plocal, SEXP BURNIN_Iterations, SEXP MCMC_Iterations, SEXP LAMBDA, SEXP DELTA)
 {
 
   SEXP   RXwork = PROTECT(duplicate(X)), RYwork = PROTECT(duplicate(Y));
-
   int nProtected = 2, nUnique=0, newmodel=0;
   int nModels=LENGTH(Rmodeldim);
   
@@ -241,7 +240,7 @@ SEXP mcmcbas(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
     REAL(shrinkage)[m] = shrinkage_m;
     prior_m  = compute_prior_probs(model,pmodel,p, modelprior);
     REAL(priorprobs)[m] = prior_m; 
-    REAL(Rbestmarg)[0] = REAL(logmarg)[m];
+
     UNPROTECT(3);
 
 
@@ -528,12 +527,7 @@ SEXP mcmcbas(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP
    REAL(logmarg)[m] = logmargy;
    REAL(shrinkage)[m] = shrinkage_m;
    REAL(priorprobs)[m] = compute_prior_probs(model,pmodel,p, modelprior);
-   //   REAL(priorprobs)[m] = beta_binomial(pmodel,p, hyper_parameters);
-   if (REAL(logmarg)[m] > REAL(Rbestmarg)[0]) {
-      for (i=0; i < p; i++) {
-	bestmodel[i] = model[i];}
-      REAL(Rbestmarg)[0] = REAL(logmarg)[m];
-    }
+
     
     if (m > 1) {
       rem = modf((double) m/(double) update, &mod);
